@@ -96,7 +96,7 @@ class DjangoModelFactory(base.Factory):
     def _get_manager(cls, model_class):
         if model_class is None:
             raise errors.AssociatedClassError(
-                "No model set on %s.%s.Meta" % (cls.__module__, cls.__name__))
+                f"No model set on {cls.__module__}.{cls.__name__}.Meta")
 
         try:
             manager = model_class.objects
@@ -173,7 +173,7 @@ class DjangoModelFactory(base.Factory):
             instance.save()
 
 
-class FileField(declarations.ParameteredDeclaration):
+class FileField(declarations.BaseDeclaration):
     """Helper to fill in django.db.models.FileField from a Factory."""
 
     DEFAULT_FILENAME = 'example.dat'
@@ -219,9 +219,9 @@ class FileField(declarations.ParameteredDeclaration):
         filename = params.get('filename', default_filename)
         return filename, content
 
-    def generate(self, params):
+    def evaluate(self, instance, step, extra):
         """Fill in the field."""
-        filename, content = self._make_content(params)
+        filename, content = self._make_content(extra)
         return django_files.File(content.file, filename)
 
 
